@@ -28,8 +28,7 @@ def setup_model(config: Coqpit):
             except ModuleNotFoundError as e:
                 raise ValueError(f"Model {config.model} not exist!") from e
     print(" > Vocoder Model: {}".format(config.model))
-    model = MyModel(config)
-    return model
+    return MyModel.init_from_config(config)
 
 
 def setup_generator(c):
